@@ -4,7 +4,7 @@ package Test::Slow;
 
 =head1 NAME
 
-Test::Slow - Skip test that are too slow to run frequently
+Test::Slow - Skip test(s) that are too slow to run frequently
 
 =head1 SYNOPSIS
 
@@ -22,21 +22,46 @@ variable to a true value:
 
    $ QUICK_TEST=1 prove --lib t/*t
 
+
+The other approach is to disable slow tests by default and run 
+them only when requested :
+
+   use Test::Slow "skip";
+   use Test::More;
+   ...
+   done_testing;
+
+To run even the slow tests, set the C<SLOW_TESTS> environment 
+variable to a true value :
+
+   $ SLOW_TEST=1 prove --lib t/*t
+
+
 =cut
 
 use warnings;
 use strict;
 use Test::More;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 BEGIN {
-    plan(skip_all => 'Slow test.') if $ENV{QUICK_TEST};
+    sub import { 
+	    my ($package, $msg) = @_; 
+
+	    if(defined $msg and $msg eq "skip") { 
+		    plan(skip_all => 'Slow test.') unless $ENV{SLOW_TEST};
+	    } else {
+		    plan(skip_all => 'Slow test.') if $ENV{QUICK_TEST};
+	    }
+    }
 }
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Tomáš Znamenáček, zoul@fleuron.cz
+Copyright 2010-2020 Tomáš Znamenáček, zoul@fleuron.cz
+
+Copyright 2020 Thibault Duponchelle, thibault.duponchelle@gmail.com
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
